#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs_1 = require("./fs");
const path_1 = require("path");
const logger_1 = require("./logger");
const default_cli_1 = require("./default-cli");
const child_process_1 = require("child_process");
const { foyFiles, registers, defaultCli } = (0, default_cli_1.initDefaultCli)();
function main() {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        var _a;
        const pkg = yield fs_1.fs.readJson('./package.json');
        const isESM = pkg.type === 'module';
        const deps = Object.assign(Object.assign({}, pkg.dependencies), pkg.devDependencies);
        const results = [];
        for (const foyFile of foyFiles) {
            let executor = defaultCli.options.executor;
            if (!executor) {
                executor = 'node';
                if (['.ts', '.cts', '.tsx', '.ctsx'].includes((0, path_1.extname)(foyFile))) {
                    if ('ts-node' in deps) {
                        executor = isESM ? 'ts-node-esm' : 'ts-node';
                    }
                    else if ('tsx' in deps) {
                        executor = 'tsx';
                    }
                    else if ('@swc-node/register' in deps) {
                        if (isESM) {
                            registers.push('@swc-node/register/esm-register');
                        }
                        else {
                            registers.push('@swc-node/register');
                        }
                    }
                    else if ('swc-node' in deps) {
                        executor = 'swc-node';
                    }
                    else {
                        logger_1.logger.error('no tsx/ts-node/swc-node or @swc-node/register found');
                        process.exit(1);
                    }
                }
            }
            const args = [
                ...registers.map((r) => `--${isESM ? 'import' : 'require'} ${r}`),
                foyFile,
                ...process.argv.slice(2),
            ];
            let NODE_OPTIONS = (_a = process.env.NODE_OPTIONS) !== null && _a !== void 0 ? _a : '';
            [
                ['--inspect', defaultCli.options.inspect],
                ['--inspectBrk', defaultCli.options.inspectBrk]
            ].map(([inspect, inspectVal]) => {
                if (inspectVal) {
                    if (typeof inspectVal === 'string') {
                        inspect += '=' + inspectVal;
                    }
                    NODE_OPTIONS += ' ' + inspect;
                }
            });
            results.push((0, child_process_1.spawn)(executor, args, {
                stdio: 'inherit',
                shell: process.platform === 'win32',
                cwd: process.cwd(),
                env: Object.assign(Object.assign({}, process.env), { NODE_OPTIONS })
            }));
        }
        for (const p of results) {
            yield new Promise((resolve) => p.on('exit', () => resolve()));
            if (p.exitCode !== 0 && p.exitCode !== null) {
                process.exitCode = p.exitCode;
            }
        }
        // fix zombie process sometimes
        process.on('SIGINT', () => {
            results.forEach((p) => {
                p.kill(9);
            });
        });
    });
}
main().catch((err) => {
    console.error(err);
    process.exitCode = 1;
});
//# sourceMappingURL=cli.js.map